from flask import Flask, render_template, request
import requests

app = Flask(__name__)

API_URL = "https://api.chenyu.cn/v1/chat/completions"
API_KEY = "sk-EbNTpBfOs4bAwH3Iev67kcrIqFnypr87LkVbWoX0qj"

# List of available models
models = [
    "Qwen/Qwen2-72B-Instruct",
    "Qwen/Qwen2-7B-Instruct",
    "meta-llama/Meta-Llama-3.1-70B-Instruct",
    "meta-llama/Meta-Llama-3.1-8B-Instruct",
    "microsoft/Phi-3-vision-128k-instruct",
    "mistralai/Codestral-22B-v0.1",
    "mistralai/Mistral-Large-Instruct-2407",
    "mistralai/Mistral-Nemo-Instruct-2407",
    "THUDM/glm-4-9b-chat"
]

# List of forbidden words
forbidden_words = ["习近平", "共产党"]  # Add other offensive terms as needed

@app.route('/', methods=['GET', 'POST'])
def index():
    if request.method == 'POST':
        # Get the user input
        user_message = request.form['user_message']
        selected_model = request.form['model']

        # Check for forbidden words
        if any(forbidden_word in user_message for forbidden_word in forbidden_words):
            reply = "Your input contains forbidden words and cannot be processed."
            return render_template('index.html', models=models, user_message=user_message, reply=reply)

        # Prepare the request payload
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {API_KEY}"
        }
        data = {
            "model": selected_model,
            "messages": [
                {
                    "role": "user",
                    "content": user_message
                }
            ],
            "temperature": 0.7
        }

        # Make the API request
        try:
            response = requests.post(API_URL, headers=headers, json=data)
            response_data = response.json()
            reply = response_data.get('choices', [{}])[0].get('message', {}).get('content', 'No response')
        except Exception as e:
            reply = f"Error: {str(e)}"

        return render_template('index.html', models=models, user_message=user_message, reply=reply)

    return render_template('index.html', models=models)

if __name__ == '__main__':
    app.run(host='0.0.0.0', port=31002, debug=True)
